@@ -1,5 +1,6 @@
 package Acme::Lambda;
 
+use 5.008;
 use warnings;
 use strict;
 use utf8;
@@ -11,7 +12,7 @@ our @EXPORT_OK = @EXPORT;
 
 sub lambda(&) {
     my $sub = shift;
-    return $sub;
+    return sub {local $_ = $_[0]; $sub->(@_)};
 }
 
 *λ = \&lambda;
@@ -22,11 +23,11 @@ Acme::Lambda - Perl with lambdas!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -38,10 +39,15 @@ Acme::Lambda brings the power of lambda to perl! It exports lambda and
     my $square = lambda { $_ * $_ };
     print $square->(4);         # 16
 
-    use utf8
+    use utf8;
     my $cube = λ {$_ * $_ * $_};
     print $cube->(3);           # 27
 
+    # The sub can also access its full argument list through @_
+    my $add = lambda {$_[0] + $_[1] } ;
+
+    print $add->(3,4);          # 7
+
 =head1 EXPORT
 
 By default, lambda and λ.
